Whatip
======

Whatip is a simple script that shows your IP. It queries well known online
IP-detection web services for that information.


Installation
============

.. code:: shell

    python -m pip install whatip

Also you can just copy whatip.py file and place it into $PATH. Do
not forget to set executable flag.


Feedback
========

Email: lorien@lorien.name
